==> haskell-haddock-library-1.4.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.4.2
id: haddock-library-1.4.2-F7UTHpERtmTC4fYnmJsN6z
key: haddock-library-1.4.2-F7UTHpERtmTC4fYnmJsN6z
license: BSD3
maintainer: Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
stability: experimental
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
exposed: True
exposed-modules:
    Documentation.Haddock.Parser Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Types Documentation.Haddock.Doc
hidden-modules: Data.Attoparsec Data.Attoparsec.ByteString
                Data.Attoparsec.ByteString.Buffer Data.Attoparsec.ByteString.Char8
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Combinator
                Data.Attoparsec.Internal Data.Attoparsec.Internal.Fhthagn
                Data.Attoparsec.Internal.Types Data.Attoparsec.Number
                Documentation.Haddock.Parser.Util Documentation.Haddock.Utf8
abi: d4edb8564f914728b25477cf99b13b1e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-library-1.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-library-1.4.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/haddock-library-1.4.2
hs-libraries: HShaddock-library-1.4.2-F7UTHpERtmTC4fYnmJsN6z
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-haddock-library-1.4.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.4.3
id: haddock-library-1.4.3-7rEGzge05s5BxGssFs5tiB
key: haddock-library-1.4.3-7rEGzge05s5BxGssFs5tiB
license: BSD3
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
stability: experimental
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
exposed: True
exposed-modules:
    Documentation.Haddock.Parser Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Types Documentation.Haddock.Doc
hidden-modules: Data.Attoparsec Data.Attoparsec.ByteString
                Data.Attoparsec.ByteString.Buffer Data.Attoparsec.ByteString.Char8
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Combinator
                Data.Attoparsec.Internal Data.Attoparsec.Internal.Fhthagn
                Data.Attoparsec.Internal.Types Data.Attoparsec.Number
                Documentation.Haddock.Parser.Util Documentation.Haddock.Utf8
abi: 77e531b98270262843f96e86f1f6f24b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-library-1.4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-library-1.4.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/haddock-library-1.4.3
hs-libraries: HShaddock-library-1.4.3-7rEGzge05s5BxGssFs5tiB
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
